import { Component } from '@angular/core';

// 引用服务
import { Router } from '@angular/router';

// 引入Parse第三方库
import * as Parse from "parse"
(Parse as any).serverURL = "http://metapunk.cn:9999/parse"
Parse.initialize("dev")


@Component({
  selector: 'app-community',
  templateUrl: './community.component.html',
  styleUrls: ['./community.component.scss']
})
export class CommunityComponent {

  scieneList: Array<Parse.Object> = [] // 科普列表
  recommendList: Array<Parse.Object> = [] // 推荐列表
  attentionList: Array<Parse.Object> = [] // 关注列表

  // 依赖注入
  constructor(private router: Router) {
    this.initPage(); // 初始化页面
  }

  // 首次进入页面，默认加载首批数据
  async initPage() {
    this.scieneList = await this.getScieneData(); // 获取科普数据
    this.recommendList = await this.getRecommendData(); // 获取推荐数据
    this.attentionList = await this.getAttentionData(); // 获取关注数据
  }

currentCate:string ='推荐'

  //页面切换
  showCate(cate:string):void {
    this.currentCate = cate;
  }

  // 数据加载相关函数
  async getScieneData() {
    let query = new Parse.Query("PetScience"); // 创建PetScience查询
    let list = await query.find(); // 执行查询
    return list; // 返回查询结果
  }

  async getRecommendData() {
    let query = new Parse.Query("PetRecommend"); // 创建PetRecommend查询
    let list = await query.find(); // 执行查询
    return list; // 返回查询结果
  }

  async getAttentionData() {
    let query = new Parse.Query("PetAttention"); // 创建PetAttention查询
    let list = await query.find(); // 执行查询
    return list; // 返回查询结果
  }

  cate: string = "推荐" // 类别，默认为"推荐"

  // 跳转函数
  goScieneDetail(sciene: Parse.Object) {
    this.router.navigate(["/lesson/community/scieneDetail"], {
      queryParams: sciene // 导航到科普详情页面，并传递科普参数
    })
  }

  goRecommendDetail(recommend: Parse.Object) {
    this.router.navigate(["/lesson/community/recommendDetail"], {
      queryParams: recommend // 导航到推荐详情页面，并传递推荐参数
    })
  }

  goAttentionDetail(attention: Parse.Object) {
    this.router.navigate(["/lesson/community/attentionDetail"], {
      queryParams: attention // 导航到关注详情页面，并传递关注参数
    })
  }
}
