import { Component } from '@angular/core';
import { ToastController } from '@ionic/angular';
import { UserService } from 'src/modules/user/service-user/user.service';
import * as Parse from "parse";

@Component({
  selector: 'app-me',
  templateUrl: './me.component.html',
  styleUrls: ['./me.component.scss']
})
export class MeComponent {

  currentUser: Parse.User | undefined;

  constructor(
    private toastCtrl: ToastController,
    public userServ: UserService
  ) {
    this.currentUser = Parse.User.current(); // 获取当前已登录的用户
  }

  async ngOnInit() {
    this.myRoleList = await this.getAttentionData(); // 获取关注数据
    this.myFoodList = await this.getScieneData(); // 获取科普数据
    this.myViewList = await this.getViewDate(); // 获取推荐分享数据
  }

  cate: string = "关注"; // 当前分类，默认为"关注"

  // 我的推荐分享
  myViewList: Array<Parse.Object> = [];
  async getViewDate() {
    let query = new Parse.Query("PetRecommend"); // 创建 PetRecommend 类的查询
    query.equalTo("user", Parse.User.current()?.toPointer()); // 查询当前用户发布的推荐分享
    query.include("user"); // 包含用户信息
    let list = await query.find(); // 执行查询
    return list; // 返回查询结果
  }

  // 我的科普关注
  myRoleList: Array<Parse.Object> = [];
  async getAttentionData() {
    let query = new Parse.Query("PetAttention"); // 创建 PetAttention 类的查询
    query.equalTo("user", Parse.User.current()?.toPointer()); // 查询当前用户发布的科普关注
    query.include("user"); // 包含用户信息
    let list = await query.find(); // 执行查询
    return list; // 返回查询结果
  }

  // 我的科普分享
  myFoodList: Array<Parse.Object> = [];
  async getScieneData() {
    let query = new Parse.Query("PetScience"); // 创建 PetScience 类的查询
    query.equalTo("user", Parse.User.current()?.toPointer()); // 查询当前用户发布的科普分享
    query.include("user"); // 包含用户信息
    let list = await query.find(); // 执行查询
    return list; // 返回查询结果
  }

  async logout() {
    await Parse.User.logOut(); // 登出当前用户
    this.currentUser = undefined; // 将当前用户设置为 undefined
    let toast = await this.toastCtrl.create({
      message: "登出成功",
      position: "top",
      duration: 500
    });
    toast.present(); // 显示登出成功的提示消息
  }

}
